#!/bin/sh

PSA_MODE=0
############################################################
# HRM silent install mode
############################################################
if [ "$1" = "--silent" ];
then
    SILENT=1
    SILENT_LOG="/tmp/postsetup.log"

    if [ "$2" = "psa" ]; then
      PSA_MODE=1
    fi
fi

Do_print()
{
    if [ "$SILENT" = "1" ]; then
      if [ "$1" != "" ]; then
        printf "HRM:%s\n" "$1" >> $SILENT_LOG
      fi
    else
      printf "%s\n" "$1"
    fi
}

Do_rpm_UVH()
{
    if [ "$SILENT" = "1" ]; then
      rpm -U "$1" >> $SILENT_LOG 2>&1
      RC=$?
    else
      rpm -Uvh "$1"
      RC=$?
    fi

    if [ "$RC" = "2" ]; then
      Do_print "Error: HRM install was failed"
      exit 1
    fi
}


Do_rpm_IVH()
{
    if [ "$SILENT" = "1" ]; then
      rpm -i "$1" >> $SILENT_LOG 2>&1
    else
      rpm -ivh "$1"
    fi
}

Do_print "HRM 8.0.0 install script for PRIMEQUEST(Linux)"
Do_print "Copyright FUJITSU LIMITED 2004-2013"
Do_print ""

############################################################
# check if login user is root
############################################################
if [ $UID != "0" ];
then
   Do_print "ERROR : login user is not root!"
   Do_print "        Please try again as root."
   exit 1
fi

FJSVhrm=FJSVhrmsr
FJSVhrm_RHEL=FJSVhrmsr-*.redhat.i686.rpm
#FJSVhrm_SUSE=FJSVhrmsr-*.suse.i686.rpm
#FJSVhrmst_RHEL4_IA64=FJSVhrmst-1.2.1-1.0.ia64.rpm

FJSVhrmcp=FJSVhrmcp-*.i386.rpm

############################################################
# HRM package check
############################################################
if [ ! -f $FJSVhrmcp ] || [ ! -f $FJSVhrm_RHEL ]; then
  Do_print "Error: HRM package can't find"
  exit 1
fi

HRM_UPDATE=0
HRM_RUN=0
HRM_SUPPORT_RHEL=0
HRM_SUPPORT_SUSE=0
SSC_SUPPORT_RHEL4_IA64=0
SE_LINUX_SUPPORT=0 # for RHEL6.2 later

RFILE="/etc/redhat-release"
SFILE="/etc/SuSE-release"
ARCH=`uname -m`

if [ "$ARCH" != "i686" ] && [ "$ARCH" != "x86_64" ]; then
  Do_print "Error: Unsupported Operating System"
  exit 1
fi

############################################################
# Support check
############################################################
# Support Check for Redhat
if [ -f $RFILE ]; then
  HRM_SUPPORT_RHEL=1

  if ( grep -q "Red Hat Enterprise Linux Server release 6" $RFILE ); then
    if ( ! grep -q "Red Hat Enterprise Linux Server release 6.0" $RFILE ) && \
       ( ! grep -q "Red Hat Enterprise Linux Server release 6.1" $RFILE ); then
      SE_LINUX_SUPPORT=1
    fi
  fi
fi

# Support Check for SuSE
#if [ -f $SFILE ]; then
#  if ( grep -q "SUSE Linux Enterprise Server" $SFILE ); then
#    HRM_SUPPORT_SUSE=1
#  fi
#fi

#
# check get SERVER_AGENT_READY is running currently
#
hrm_get_server_agent_ready_stop()
{
	fjsvhrmpid=`/bin/ps -eo pid,comm | /bin/grep -w 'hrmsched' | /usr/bin/awk '{print $1}'`
	if [ -n "$fjsvhrmpid" ]; then
		HRM_RUN=1
	fi

	fjsvhrmpid=`/bin/ps -eo pid,comm | /bin/grep 'FJSVhrm' | /usr/bin/awk '{print $1}'`
	if [ -n "$fjsvhrmpid" ]
	then
		HRM_RUN=1
		kill -TERM $fjsvhrmpid >/dev/null 2>&1

		hrmgetpid=`/bin/ps -eo pid,args | /bin/grep -w '/opt/FJSVhrm/bin/get SERVER_AGENT_READY' | /bin/grep -v grep | /usr/bin/awk '{print $1}'`
		if [ -n "$hrmgetpid" ]
		then
			kill -TERM $hrmgetpid >/dev/null 2>&1
			sleep 1
		fi
	fi
}

############################################################
# check package type
############################################################
server_type_check()
{
        server_type=""
        if [ -f /var/opt/FJSVhrm/config/server_type ]
        then
                server_type=`cat /var/opt/FJSVhrm/config/server_type`
        fi
}

############################################################
# FJSVhrm
############################################################
Do_install_FJSVhrm () {

  rpm -q $FJSVhrm > /dev/null 2>&1
  if [ "$?" = "0" ]; then
    HRM_UPDATE=1
    server_type_check
    if [ "$server_type" != "PQ" ]; then
      PSA_MODE=1
    fi
  elif [ -d /opt/FJSVhrm/ ]; then
    Do_print "Error: HRM already installed. HRM package type error."
    exit 1
  elif [ "$SILENT" != "1" ]; then
    printf " ==== HRM Install Mode ====\n"
    printf "\n"
    printf "  1: PSA mode\n"
    printf "  2: ServerView mode\n"
    printf "\n"
    while :
    do
      printf "Select HRM Install Mode [1 or 2]:"; read "key"
      if [ "$key" = "1" ] ; then
        PSA_MODE=1
        break
      elif [ "$key" = "2" ] ; then
        PSA_MODE=0
        break
      fi
    done
  fi

  if [ $PSA_MODE = "1" ]; then
    CUSTOMIZE=customizeSR
    Do_print "HRM Install: PSA mode."
  else
    CUSTOMIZE=customizePQ
    Do_print "HRM Install: ServerView mode."
  fi

  hrm_get_server_agent_ready_stop

  if [ "$HRM_SUPPORT_RHEL" = "1" ] ; then
    Do_print "install $FJSVhrm, please wait..."
    sleep 1
    Do_rpm_UVH $FJSVhrm_RHEL
#  elif [ "$HRM_SUPPORT_SUSE" = "1" ] ; then
#    Do_print "install $FJSVhrm, please wait..."
#    sleep 1
#    Do_rpm_UVH $FJSVhrm_SUSE
  else
    Do_print "Error: Unsupported Operating System"
    exit 1
  fi

  rpm -q $FJSVhrm  > /dev/null 2>&1
  if [ "$?" = "0" ]; then
    if [ "$HRM_UPDATE" != "1" ] && [ $PSA_MODE != "1" ]; then
      echo "PQ"      > /var/opt/FJSVhrm/config/server_type
    fi
    if [ "$HRM_UPDATE" != "1" ] && [ "$SILENT" != "1" ]; then
      touch /var/opt/FJSVhrm/data/hrm_agent_enabled
    fi
    Do_print "HRM install was successful."
  else
    Do_print "Error: HRM install was failed"
    exit 1
  fi
}

Do_install_FJSVhrm

############################################################
# FJSVhrmcp (Cipher/proxy)
############################################################
Do_install_FJSVhrmcp () {

  rpm -q FJSVhrmcp  > /dev/null 2>&1
  if [ "$?" = "0" ]; then
    HRM_UPDATE=1
  fi

  if [ "$HRM_SUPPORT_RHEL" = "1" ] ; then
    Do_print "install FJSVhrmcp, please wait..."
    sleep 1
    Do_rpm_UVH $FJSVhrmcp
#  elif [ "$HRM_SUPPORT_SUSE" = "1" ] ; then
#    Do_print "install FJSVhrmcp, please wait..."
#    sleep 1
#    Do_rpm_UVH $FJSVhrmcp
  else
    Do_print "Error: Unsupported Operating System"
    exit 1
  fi

  rpm -q FJSVhrmcp  > /dev/null 2>&1
  if [ "$?" = "0" ]; then
#    if [ "$HRM_UPDATE" != "1" ]; then
#      touch /var/opt/FJSVhrm/data/hrm_agent_enabled
#    fi
    Do_print "FJSVhrmcp install was successful."
  else
    Do_print "Error: FJSVhrmcp install was failed"
    exit 1
  fi
}

Do_install_FJSVhrmcp

############################################################
# FJSVhrmst (SANTool)
############################################################
Do_install_SANTool () {
  if [ "$SSC_SUPPORT_RHEL4_IA64" != "1" ]; then
    return 0
  fi

  Do_print ""
  Do_print "install FJSVhrmst, please wait..."
  sleep 1

  rpm -q FJSVhrmst >/dev/null 2>&1
  if [ "$?" = "0" ]; then
    Do_print "Warning: Already FJSVhrmst installed."
    Do_print "If you upgrade to FJSVhrmst, and please backup & uninstall & install FJSVhrmst."
    return 0
  fi

  Do_rpm_IVH $FJSVhrmst_RHEL4_IA64

  rpm -q FJSVhrmst >/dev/null 2>&1
  if [ "$?" = "0" ]; then
    Do_print "FJSVhrmst install was successful."
  else
    Do_print "Error: FJSVhrmst install was failed."
    return 1
  fi
}

# Do_install_SANTool

############################################################
# Update configuration file
############################################################
/opt/FJSVhrm/bin/config_updater 2>/dev/null

############################################################
# Customize Install
############################################################
Do_install_Customize () {
  if [ ! -d $CUSTOMIZE ]; then
    return 0
  fi

  rpm -q $FJSVhrm  > /dev/null 2>&1
  if [ "$?" != "0" ]; then
    return 0
  fi

  rpm -q FJSVhrmcp  > /dev/null 2>&1
  if [ "$?" != "0" ]; then
    return 0
  fi

  set - $CUSTOMIZE/FJSVhrm_opt      /opt/FJSVhrm        \
        $CUSTOMIZE/FJSVhrm_varopt   /var/opt/FJSVhrm    \
        $CUSTOMIZE/FJSVhrmcp_opt    /opt/FJSVhrmcp      \
        $CUSTOMIZE/FJSVhrmcp_varopt /var/opt/FJSVhrmcp

  Do_print ""
  Do_print "custom installing"

  backdir=`pwd`
  while [ $# != 0 ]
  do
    cust="$1"
    targ="$2"

    if [ -d "$cust" ]; then
      cd "$cust"
      find * -type f | while read name
      do
        if [ -f "$targ/$name" ] ;then
          cp "$targ/$name" "$targ/$name".org 2>/dev/null # Backup
          cp "$name" "$targ/$name"        2>/dev/null # Customize copy
          if [ $? = 0 ]; then
            r="ok"
          else
            r="fail"
          fi
        else
          cp "$name" "$targ/$name"        2>/dev/null # Customize copy
          if [ $? = 0 ]; then
            r="ok"
            chown root:root "$targ/$name"
            chmod 600 "$targ/$name"
          else
            r="fail"
          fi
        fi

        Do_print "* $targ/$name $r"
      done

      cd "$backdir"
    fi
    shift 2
  done

  # HRM_log for hrmsnap
  if [ -d $CUSTOMIZE ]; then
    cp -rp $CUSTOMIZE /var/opt/FJSVhrm/log/
  fi
}

Do_install_Customize

############################################################
# HRM SELinux Module Install
############################################################
SE_FJSVhrm=se_fjsvhrm

Do_install_SELinux_module () {
  if [ "$SE_LINUX_SUPPORT" = "0" ]; then
    return 0
  fi

  # semodule check
  rpm -q policycoreutils > /dev/null 2>&1
  if [ "$?" != "0" ]; then
    return 0
  fi

  Do_print "Attempting to install module '$SE_FJSVhrm', please wait..."
  semodule -i /opt/FJSVhrm/bin/$SE_FJSVhrm.pp
  if [ "$?" = "0" ]; then
    semodule -l |/bin/grep -wq $SE_FJSVhrm
    if [ "$?" = "0" ]; then
      Do_print "'$SE_FJSVhrm' attempt was successful."
    else
      Do_print "Error: '$SE_FJSVhrm' attempt was failed"
      exit 1
    fi
  else
    Do_print "Error: '$SE_FJSVhrm' attempt was failed"
    exit 1
  fi
}

Do_install_SELinux_module

############################################################
# HRM Install Checker
############################################################
/opt/FJSVhrm/bin/hrm_install_check.sh -o /var/opt/FJSVhrm/data/INSTALL_CHECKER_1.txt 2>/dev/null

############################################################
# FJSVhrm Update status check
############################################################
if [ "$HRM_UPDATE" = "1" ] && [ "$HRM_RUN" = "0" ]; then
  exit 0
fi

############################################################
# FJSVhrm Start
############################################################

cd /

if [ -f /var/opt/FJSVhrm/data/hrm_agent_enabled ]; then
  Do_print ""
  if [ -f /etc/rc.d/init.d/FJSVhrm ]; then
    /etc/rc.d/init.d/FJSVhrm start
  elif [ -f /etc/init.d/FJSVhrm ]; then
    /etc/init.d/FJSVhrm start
  fi
  Do_print "FJSVhrm start."
fi

exit 0
