#!/bin/sh
# HRM Install Checker, Copyright Fujitsu Limited 2004-2013
# All Right Reserved
#

.  `dirname $0`/common_lib.sh


#
# determine model (PG or PCS)
#
model=""
if [ -f /var/opt/FJSVhrm/config/server_type ]
then
	model=`cat /var/opt/FJSVhrm/config/server_type`

elif [ -f `dirname $0`/server_type ]
then
	f=`dirname $0`/server_type
	model=`cat $f`
fi

if [ "$model" = "PG" ]
then
	modelcode="G"		# use G (PRIMERGY)
	echo "$title21"
	echo "$title22"
	echo "$title24"
	echo "$title25"
	hrmpkg="FJSVhrm"
elif [ "$model" = "PCS" ]
then
	modelcode="S"		# use S (PC/server)
	echo "$title41"
	echo "$title42"
	echo "$title44"
	echo "$title45"
	hrmpkg="FJSVhrmpcs"
else
	if [ "$model" = "SR" ]
	then
		modelcode="R1"           # R:PRIMEQUEST 1000 PSA mode
	elif [ "$model" = "PQ" ]
	then
		modelcode="R2"           # R:PRIMEQUEST 1000 ServerView mode
	else
		modelcode="R"            # R:PRIMEQUEST 1000 PSA/ServerView mode
	fi
	hrmpkg="FJSVhrmsr"
	echo "$title31"
	echo "$title32"
	echo "$title34"
	echo "$title35"
fi

if [ -f /opt/FJSVhrm/update/pkg_type ] 
then
	hrmpkg=`cat /opt/FJSVhrm/update/pkg_type`
fi


echo "Date: " `date "+%Y-%m-%d %H:%M:%S"`
echo ""

#
# OS check
# output:
#     osname ... title string
#     ostype ... identifier, one of
#       PG/PCS: vmware, 5, 6
#       SR:     vmware, 5, 6
#
section "$oschk_00"

init
r=`/bin/hostname`
x=`echo "$r" | tr -d '[\040-\177]'`
if [ "$x" != "" ]
then
        str1="$oschk_05"
fi
title  "$oschk_04" "$r"


redhat_rel="/etc/redhat-release"
suse_rel="/etc/SuSE-release"

init
if [ -x /usr/bin/vmware ]			# VMware
then
	vmware_version=`/usr/bin/vmware -v`
	osname="$vmware_version"
	ostype="vmware"

elif [ -f "$redhat_rel" ] ; then				# this is RedHat Linux

	if grep "Oracle VM server" $redhat_rel >/dev/null
	then
		osname="OracleVM"
	elif grep "Enterprise" $redhat_rel >/dev/null
	then
		osname="RHEL"				# RHEL5/6
	fi	
	
	if grep "release 5" $redhat_rel >/dev/null
	then
		ostype="5"
		osname="${osname}5"
	elif grep "release 6" $redhat_rel >/dev/null
	then
		ostype="6"
		osname="${osname}6"
	elif grep "Oracle VM server release 3" $redhat_rel >/dev/null
	then
		ostype="5"
		osname="${osname}3"
	else
		# unsupported RedHat version
		str1="$oschk_07 `cat $redhat_rel`"
	fi

elif [ -f "$suse_rel" ]; then				# this is SUSE Linux
	str1="$oschk_07 `cat $suse_rel`"
else
	str1="$oschk_07 unknown"
fi

title  "$oschk_01" $osname" "`/bin/uname -r`" "`/bin/uname -m`

if [ "$nr_err" != 0 -a "$FORCE_CHECK" = "" ]		# finish if failed
then				# Note: nr_err is counted up in the common_lib.sh
	end
fi


# Package Software Check

#
# OS            Prerequisite Packages
# --------------------------------------
# RHEL5/6       compat-libstdc++-33
# VMware4       compat-libstdc++-33
# common        glibc gawk grep libstdc++ rpm bash sed perl libgcc net-snmp
#               srvmagt-agents

# format:
#   pkgname/version/architecture
#     
#    architecture must be "32" or "" 
#    where
#         "32" : %arch must not x86_64
#         ""   : do no check
#

commonlibs="glibc/0/32 gawk/0 grep/0 rpm/0 bash/0 sed/0 perl/0"
commonlibs="$commonlibs  libgcc/0/32"

if [ "$modelcode" = "G" -o "$modelcode" = "S" ]
then
	commonlibs="$commonlibs libstdc++/0"
	case "$ostype" in
	5|6)
		libs="compat-libstdc++-33/0/32" 	;;
	*)
		libs="" ;;
	esac
else
	commonlibs="$commonlibs libstdc++/0/32"
	libs=""
fi

if [ "$modelcode" = "G" ]
then
	commonlibs="$commonlibs srvmagt-agents/4.60"
elif [ "$modelcode" = "R1" ]
then
	commonlibs="$commonlibs FJSVpsa/0"
elif [ "$modelcode" = "R2" ]
then
	commonlibs="$commonlibs srvmagt-agents/0 SVmco/0"
elif [ "$modelcode" = "R" ]
then
	commonlibs="$commonlibs srvmagt-agents/0 SVmco/0 FJSVpsa/0"
fi

for data in $libs $commonlibs
do
	init
	save="$IFS"; IFS="/"; set - $data ; IFS="$save"

	pkg="$1"
	c_ver="$2"
	c_arch="$3"
	ver=""
	if rpm -q $pkg >/dev/null
	then
		ver=`rpm -q --queryformat '%{VERSION}-%{RELEASE}(%{ARCH})' $pkg`

		if [ "$c_ver" != "0" ]
		then
			a_ver=`rpm -q --queryformat '%{VERSION}' $pkg`
			a_rev=`rpm -q --queryformat '%{RELEASE}' $pkg`

			nor_c_ver=`printf "%08.2f" "$c_ver"`	     # assume X.XX
			nor_a_ver=`printf "%08.2f" "$a_ver"`	     # assume X.XX

			if expr "$nor_c_ver" \> "$nor_a_ver" >/dev/null
			then
				str1=`printf "$esfchk_06" "$pkg" "$ver" "$ver_c"`
			fi
		fi

		if [ "$c_arch" = "32" ]		# arch must not be x86_64
		then
			a_arch=`rpm -q --queryformat '%{ARCH}' $pkg`
			if [ "$a_arch" = "x86_64" ]
			then
				str2=`printf "$esfchk_12"`
			fi

		fi
	else
		#
		# warning if it is perl
		#
		if expr "$pkg" : "perl" >/dev/null 2>&1 
		then
			str1=`printf "$esfchk_11" "$pkg"`
		else
			str1=`printf "$esfchk_05" "$pkg"`
		fi

		if [ "$modelcode" = "R" ]
		then
			if expr "$pkg" : "srvmagt-agents" >/dev/null 2>&1 
			then
				str1=`printf "$esfchk_11" "$pkg"`
			elif expr "$pkg" : "srvmagt-eecd" >/dev/null 2>&1 
			then
				str1=`printf "$esfchk_11" "$pkg"`
			elif expr "$pkg" : "SVmco" >/dev/null 2>&1 
			then
				str1=`printf "$esfchk_11" "$pkg"`
			elif expr "$pkg" : "FJSVpsa" >/dev/null 2>&1 
			then
				str1=`printf "$esfchk_11" "$pkg"`
			fi
		fi
	fi
	title "$pkg" "$ver"
done

#
# module check
#
for mod in sg
do
	init
	if /sbin/lsmod | awk '{print $1}' | grep "^$mod\$" >/dev/null
	then
		:
	else
		str1="$esfchk_07"
	fi
	title "$mod"
done



#
# Disk Space
#
section "$dskchk_00"
for data in "/opt 133120 200000" "/var/opt 71680 200000"
do
	init
	set - $data
	targ=$1
	limitsize=$2	# required disk space when HRM is not installed yet
	enoughsize=$3	# expected disk space even if HRM is installed or not

	avail=`/bin/df -kP $targ | /bin/sed -n 2p | awk '{print $4}'`
	if [ "$avail" != "" ]
	then
		if rpm -q "$hrmpkg" >/dev/null
		then
			:
		elif [ $avail -lt "$limitsize" ]
		then
			str1=`printf "$dskchk_01"  $targ  $limitsize`
		fi

		if [ "$str1" = "" ]
		then
			if [ $avail -lt "$enoughsize" ]
			then
				str1=`printf "$dskchk_02"  $targ`
			fi
		fi

		title "$targ" "$avail Kbyte"
	fi
done



#
# Port check
# if /etc/services contains 9977 , print warning
#
section "$portchk_00"
for data in "9977 hrmport" "9980 hrmsched" "9981 hrmlocal"
do
	set - $data
	port=$1
	servname=$2

	init
	if grep "$port/tcp" /etc/services | grep -v '^#' | grep -vw $servname >/dev/null ; then
		str1=`printf "$portchk_01" $port`
	fi
	title $port 
done




#
# community check
#
comm_check()
{
	if [ "$modelcode" = "S" ]
	then
		return			# if PC/server mode
	fi

	if [ ! -x /opt/FJSVhrm/bin/sv_community -a ! -x /opt/FJSVhrm/bin/psa_community ]
	then
		return			# return if sv_community psa_community not found
	fi

	if [ "$modelcode" = "R1" ]; then
		section "$comchk_01"
	else
		section "$comchk_00"
	fi

	init	
	if [ "$modelcode" = "R1" ]; then
		comm=`/opt/FJSVhrm/bin/psa_community`
	else
		comm=`/opt/FJSVhrm/bin/sv_community`
	fi
	ret=$?
	if [ $ret = 0 ]; then
		mode="(auto)"
	else
		mode="(manual)"
	fi

	if [ "$comm" = "" ]
	then
		str1="$comchk_05"		# no serverview/psa community 
	fi
	title  "community" "\"$comm\"$mode"

	#
	# If community is public and /usr/bin/snmpwalk exists,
	#  try SNMP communication check.
	#
	if [ "$str1" = "" -a "$str2" = "" -a -x "/usr/bin/snmpwalk" ]
	then
		init
		result=`/usr/bin/snmpwalk -c "$comm" -v1 127.0.0.1 system.1.0 2>/dev/null | grep '='`
		if [ "$result" = "" ]
		then
			str1=`printf "$comchk_04" "system" "$comm"`	# failed to connect to snmpd
		fi

		if [ "$modelcode" = "R1" ]; then
			oid=".1.3.6.1.4.1.211.1.31.1.2.100.6.1.3.0" # PSA 
		else
			oid=".1.3.6.1.4.1.231.2.10.2.11.2.1"        # ServerView
		fi
		result=`/usr/bin/snmpwalk -c "$comm" -v1 127.0.0.1 "$oid" 2>/dev/null | grep '='`
		if [ "$result" = "" ]
		then
			str2=`printf "$comchk_04" "$oid" "$comm"`	# failed to connect to snmpd...
		fi
		title  "access test"
	fi
}



#
# HRM Package check
#
section "$hrmchk_00"
init
if rpm -q "$hrmpkg" >/dev/null
then
	ver=`rpm -q --queryformat '%{VERSION}-%{RELEASE}' $hrmpkg`

	#
	# Note: if version is 3.1.1 or less than 3.1.0, it contains 
	#  the tape rewind problem.
	#
	hrmver=`rpm -q --queryformat '%{VERSION}' $hrmpkg`  # 3.1 or 3.1.1 or 3.0.10
	vernum=`echo "$hrmver" | awk -F. '{printf "%d%d", $1, $2}'`
	if [ "$hrmver" = "3.1.1" -o "$vernum" -lt 31 ]
	then
		str1="$hrmchk_04"
	fi
else
	ver=""
	str1="$hrmchk_01"
fi
title "$hrmpkg" "$ver"



#
# SDB agent check
#
section "$sdbagt_00"
init
sdb="not found"
if [ -f /opt/sdb/bin/sdb_timer.bin ]
then
        # sdb is installed
        str1="$sdbagt_01"

        if /bin/ps -eo args | grep '[/]opt/sdb/bin/sdb_timer.bin' >/dev/null
        then
                str1="$sdbagt_02"
        fi
fi
title "SDB RA"

init
if [ -f /etc/syslog.conf ]
then
	if grep '^#ce' /etc/syslog.conf >/dev/null 
	then
		if grep '^\*\.info[ 	]*@' /etc/syslog.conf >/dev/null
		then
			str1="$sdbagt_03"
		fi
	fi
fi
title "SDB syslog"

if rpm -q "$hrmpkg" >/dev/null ; then
	:
else
	comm_check		# community check
	end
fi


#
# hrmsched check
#
section "$schchk_00"
init
if /bin/ps -el | grep hrmsched >/dev/null
then
	:				# sched is running
else
	if [ ! -f /var/opt/FJSVhrm/data/hrm_agent_enabled ]
	then
		str1="$schchk_01"
	fi

	if [ -f /var/opt/FJSVhrm/log/sched_log ]
	then
		if tail -1 /var/opt/FJSVhrm/log/sched_log | \
		   grep 'for the specified address is already in use' >/dev/null
		then
			str1="$schchk_02"
		fi

		if tail -1 /var/opt/FJSVhrm/log/sched_log | \
		   grep 'alive_check:hrm scheduler abnormally terminated' >/dev/null
		then
			str2="$schchk_03"
		fi

		if tail -1 /var/opt/FJSVhrm/log/sched_log | \
		   grep 'alive_check:hrm scheduler ends normally.' >/dev/null
		then
			str3="$schchk_04"
		fi

		if [ "$str1" = "" -a "$str2" = "" -a "$str3" = "" ]
		then
			str1="$schchk_07"
		fi
	fi
fi
title "$schchk_10"


#
# devconf
#
if [ -f /var/opt/FJSVhrm/log/sched_log ]
then
	init
	if [ ! -f /var/opt/FJSVhrm/data/devconf_cur.xml ]
	then
		str1="$schchk_06"
	fi
	title "$schchk_11"
fi

	comm_check		# community check

end



