#!/bin/sh 

#pidfile="$HRM_data/remote.pid"
snapdir="$HRM_temp/hrmsnap"
sendname="$HRM_data/remote.sendname"	# filename for "remcs send"

lockfile="$HRM_data/snap.lock"		# mutuality of snap.sh
plockfile="$HRM_data/snapprog.lock"	# mutuality of updating remote.progress

HRM_SNAP_TIMEOUT=290 export HRM_SNAP_TIMEOUT  # timeout value used by snap.aout

#
# make work directory
#
	tmpdir="$HRM_temp"
	if [ "$tmpdir" = "" ]
	then
		tmpdir="/tmp"
	fi
	workdir="$tmpdir/snapwork"
	mkdir $workdir 2>/dev/null
	if [ ! -d $workdir ]
	then
		$HRM_bin/hrmevent "I0700:failed to make $workdir."
		rm -f $pidfile
		exit 1
	fi

#
# tracefile
#
tracefile="$HRM_log/snap_hrmsnap_log"
tracefileold="$HRM_log/snap_hrmsnap_log.0"
tracemax=65535
touch $tracefile
size=`/usr/bin/wc -c < $tracefile`
if [ "$size" -gt "$tracemax" ]
then
	mv $tracefile $tracefileold
	touch $tracefile
fi

#
# trace function -- write log message to the trace log
#    Usage: trace msg
trace()
{
	echo `/bin/date "+%D %T"` " $1" >> $tracefile
}

#
# progress function -- write progress (extrep snap)
#    Usage: update_progress percent
update_progress()
{
	#$HRM_bin/mutexlock -t 10 -l $plockfile 2>/dev/null
	echo "$1 100" > $progressfile
	#$HRM_bin/mutexlock -u $plockfile 2>/dev/null
}



trace	"* snap_hrmsnap.sh($$) start arg=\"$1\" \"$2\""

#
# call mutexlock to mutual exclusion.
# enabled to start snap.sh simultaneously, but only 1 process can work, 
# other processes are waiting here.
#
# $HRM_bin/mutexlock -t $HRM_SNAP_TIMEOUT -l $lockfile 2>/dev/null
# if [ $? != 0 ]			# lock timeout
# then
# 	trace	"mutexlock timeout (lockfile $lockfile)"
# 	sleep 1
# 	pid=`cat $pidfile`
# 	if [ "$pid" != "" ]
# 	then
# 		if kill -0 $pid >/dev/null 2>&1
# 		then
# 			trace "previous snap.sh($pid) is still alive"
# 			$HRM_bin/hrmevent "E0737:timeout of snap/remote process. (<<$1 $2>>, <<300>>)"
# 			exit 2			# returns with busy 
# 		fi
# 		trace "previous snap.sh($pid) is not found."
# 	fi
# 	$HRM_bin/hrmevent "W0738:previous snap process seems abnormaly stopped."
# 	rm -f $lockfile				# trouble??
# 	$HRM_bin/mutexlock -t 10 -l $lockfile 2>/dev/null
# 	trace "mutexlock retry returns $?"
# fi

echo "$$" > $pidfile
trace	"* getlock($$) succeed"

#
# main process
#    snap                 .... archive HRM logs
#
#
case "$1" in 
snap)
	filename=$tmpdir/hrmlog.hrm
	resultfile=$HRM_data/remote.result
	progressfile=$snapdir/.snap_progress # FileName Changed. 
	tmp1=$HRM_temp/extrep_snap.tmp
	cancelmsg=$HRM_data/remote.cancelmsg
	if [ -f $resultfile ]				# if result of previous run is error, clear it
	then
		is_err=`/bin/cat $resultfile | grep 'ERROR'`
		if [ "$is_err" != "" ]
		then
			trace "previous run is error, clear it."
			rm $resultfile
		fi
	fi

	#echo "I0715:snap is finished." > $cancelmsg
	sleep 3						# to know extrep that snap_hrmsnap.sh starts
	#$HRM_bin/hrmevent "I0714:snap is started."
	trace "I0714:snap is started." # hrmevent->trace Changed 
	touch $HRM_data/remote.starttime

	update_progress 5   # 5% (10%->5% Changed )


	# creat archive
	trace	"call snap.aout"
	$HRM_bin/snap.aout -d $workdir snap
	if [ $? != 0 ]
	then
		trace "E0733:failed to gather HRM logs."
		#$HRM_bin/hrmevent 
		#echo "ERROR E0733:failed to gather HRM logs." > $resultfile
		update_progress 50   # 50% (100%->50% Changed )
		rm -rf $workdir
		rm -f $filename
		#rm -f $pidfile
		#$HRM_bin/hrmevent "I0715:snap is finished."
		trace "I0715:snap is finished." # hrmevent->trace Changed 
		#rm -f $cancelmsg
#		$HRM_bin/mutexlock -u $lockfile 2>/dev/null
		exit 1
	fi

	update_progress 25   # 25% (50%->25% Changed )

##	# create HRMsnap
##        if [ -f $snapdir/.snap_pid ]
##        then
##		trace	"found $snapdir/.snappid"
##                if /bin/pflags `cat $snapdir/.snap_pid` >/dev/null 2>&1 
##                then
##			trace "found the snap process is alive"
##                        $HRM_bin/hrmevent "E0736:hrmsnap is already running."
##                        echo "ERROR E0736: hrm snap is already running." > $resultfile
##			update_progress 100			# 100%
##			rm -rf $workdir
##			rm -f $filename
##			rm -f $pidfile
##			$HRM_bin/hrmevent "I0715:snap is finished."
##			rm -f $cancelmsg
###			$HRM_bin/mutexlock -u $lockfile 2>/dev/null
##                        exit 2
##                fi
##        fi
##
##	trace	"call hrmsnap.sh"
##	$HRM_bin/hrmsnap.sh > $tmp1
##	dname=`grep directory $tmp1 | awk '{print $NF}'`
##	fname=`grep filename $tmp1 | awk '{print $NF}'`
##	rm -f $tmp1
##
##	if [ ! -f "$dname/$fname" ]
##	then
##		trace	"E0734: hrmsnap.sh failed."
##		$HRM_bin/hrmevent "E0734:hrmsnap failed."
##		echo "ERROR E0734:hrmsnap failed." > $resultfile
##		update_progress 100				# 100%
##		cd $workdir/..
##		rm -rf $workdir
##		rm -f $filename
##		rm -f $pidfile
##		$HRM_bin/hrmevent "I0715:snap is finished."
##		rm -f $cancelmsg
###		$HRM_bin/mutexlock -u $lockfile 2>/dev/null
##		exit 1
##	fi

	cd $workdir/hosts/*/snap
	if [ $? != 0 ]
	then
		trace "Error: directory $workdir/hosts/(any)/snap is not exist."
		#$HRM_bin/hrmevent "E0733:failed to gather HRM logs."
		trace "E0733:failed to gather HRM logs." # hrmevent->trace Changed 
		#echo "ERROR E0733:failed to gather HRM logs." > $resultfile
		update_progress	50   # 50% (100%->50% Changed )
		cd $workdir/..
		rm -rf $workdir
		rm -f $filename
		#rm -f $pidfile
		#$HRM_bin/hrmevent "I0715:snap is finished."
		trace "I0715:snap is finished." # hrmevent->trace Changed 
		#rm -f $cancelmsg
#		$HRM_bin/mutexlock -u $lockfile 2>/dev/null
		exit 1

	fi

##	update_progress 70				# 70%
##
##	#
##	# extract hrmsnap
##	#
##	trace	"extract hrmsnap"
##	sname=`head -1 $dname/$fname | awk '{print $NF}'`
##	/bin/uudecode $dname/$fname
##	mv $sname ${sname}.slc
##	$HRM_bin/slca xy ${sname}.slc >/dev/null 2>&1
##	if [ $? != 0 ]
##	then
##		$HRM_bin/hrmevent "W0735:HRM snap archive was broken."
##	fi
##	rm -f ${sname}.slc
##	rm -f ${dname}/$fname
##

	update_progress 40   # 40% (80%->40% Changed )
	#cp /dev/null $cancelmsg			# unable to cancel below

	#
	# discard previous collected data
	#
	#rm -f $resultfile
	#rm -f ${filename}.uue

	#
	# archive all (slca or zip)
	# 
	#trace	"archive again."
	#cd $workdir
	err=0
#	if [ ! -f /etc/SuSE-release ]
#	then
#		rm -f $filename ${filename}.slc
#		$HRM_bin/slca afry $filename  customers hosts  >/dev/null 2>$HRM_log/extrep_slca_error.log
#		arc_file="${filename}.slc"
#		arc_type="hrm"
#	else
	#	rm -f $filename ${filename}.zip
	#	/usr/bin/zip -r ${filename}.zip customers hosts  >/dev/null 2>$HRM_log/extrep_zip_error.log
	#	arc_file="${filename}.zip"
	#	arc_type="zip"
#	fi

	#if [ ! -s "$arc_file" ]
	#then
	#	cd ..
	#	rm -rf $workdir
	#	rm -f $arc_file
	#	trace	"archive failed (see extrep_slca_error.log)"
		#$HRM_bin/hrmevent "E0730:failed to create archive, $arc_file."
	#	trace "E0730:failed to create archive, $arc_file." # hrmevent->trace Changed 
		#echo "ERROR E0730:failed to create archive. $arc_file" > $resultfile
	#	update_progress 50   # 50% (100%->50% Changed )
		#$HRM_bin/hrmevent "I0715:snap is finished."
	#	trace "I0715:snap is finished." # hrmevent->trace Changed 
		#rm -f $pidfile
		#rm -f $cancelmsg
#	#	$HRM_bin/mutexlock -u $lockfile 2>/dev/null
	#	exit 1
	#fi

	#cd ..
	#rm -rf $workdir
	rm -f $tmp1
	#mv $arc_file $filename

	update_progress 45   # 90%->45% Changed 

	#
	# uuencode, then make resultfile
	#
	#trace	"count byte size of the slca file"
	#size=`wc -c < $filename`
	#trace	"size=$size, then do uuencode"
	#$HRM_bin/uuencode $filename $size > ${filename}.uue
	#trace	"count lines of uuencoded file"
	#lines=`wc -l < ${filename}.uue`
	#trace	"lines=$lines"

	#sendfilename=`/bin/date "+U_00000000_%Y%m%d_%H%M%S.${arc_type}"`
	#echo "$sendfilename" > $sendname
	#echo "$sendfilename $lines $size " `$HRM_bin/hrmdate` \
	#	| awk '{print $1 " " $2 " " $3 " " $4}' > $resultfile
	#

	update_progress 50   # 50% (100%->50% Changed )

	#$HRM_bin/hrmevent "I0724:HRM snap data was created completely."
	trace "I0724:HRM snap data was created completely." # hrmevent->trace Changed 
	#$HRM_bin/hrmevent "I0715:snap is finished."
	trace "I0715:snap is finished." # hrmevent->trace Changed 
	#rm -f $pidfile
	#rm -f $cancelmsg
	trace	"completed"
#	$HRM_bin/mutexlock -u $lockfile 2>/dev/null
	;;

*)
	#rm -f $pidfile
#	$HRM_bin/mutexlock -u $lockfile 2>/dev/null
	;;
esac
trace	"* snap_hrmsnap.sh completed."
exit 0
